@@ -271,21 +271,24 @@ class SpecifyModel(BaseInterface):
             each run
         """
         sessinfo = []
+        output_units = 'secs'
+        if 'output_units' in self.inputs.traits():
+            output_units = self.inputs.output_units
         for i, info in enumerate(infolist):
             sessinfo.insert(i, dict(cond=[]))
             if isdefined(self.inputs.high_pass_filter_cutoff):
                 sessinfo[i]['hpf'] = np.float(self.inputs.high_pass_filter_cutoff)
-            if hasattr(info, 'conditions') and info.conditions:
+            if hasattr(info, 'conditions') and info.conditions is not None:
                 for cid, cond in enumerate(info.conditions):
                     sessinfo[i]['cond'].insert(cid, dict())
                     sessinfo[i]['cond'][cid]['name']  = info.conditions[cid]
                     sessinfo[i]['cond'][cid]['onset'] = scale_timings(info.onsets[cid],
                                                                      self.inputs.input_units,
-                                                                     'secs',
+                                                                     output_units,
                                                                      self.inputs.time_repetition)
                     sessinfo[i]['cond'][cid]['duration'] = scale_timings(info.durations[cid],
                                                                         self.inputs.input_units,
-                                                                        'secs',
+                                                                        output_units,
                                                                         self.inputs.time_repetition)
                     if hasattr(info, 'amplitudes') and info.amplitudes:
                         sessinfo[i]['cond'][cid]['amplitudes']  = info.amplitudes[cid]
@@ -321,7 +324,12 @@ class SpecifyModel(BaseInterface):
             for i, out in enumerate(outliers):
                 numscans = 0
                 for f in filename_to_list(sessinfo[i]['scans']):
-                    numscans += load(f).get_shape()[3]
+                    shape = load(f).get_shape()
+                    if len(shape) == 3 or shape[3] == 1:
+                        iflogger.warning("You are using 3D instead of 4D files. Are you sure this was intended?")
+                        numscans += 1
+                    else:
+                        numscans += shape[3]
                 for j, scanno in enumerate(out):
                     colidx = len(sessinfo[i]['regress'])
                     sessinfo[i]['regress'].insert(colidx, dict(name='', val=[]))
@@ -457,7 +465,7 @@ class SpecifySPMModel(SpecifyModel):
         return [infoout], nscans
 
     def _generate_design(self, infolist=None):
-        if not isdefined(self.inputs.concatenate_runs):
+        if not isdefined(self.inputs.concatenate_runs) or not self.inputs.concatenate_runs:
             super(SpecifySPMModel, self)._generate_design(infolist=infolist)
             return
         if isdefined(self.inputs.subject_info):
