@@ -50,49 +50,50 @@ def test_ad_output_filenames():
     ad = ra.ArtifactDetect()
     outputdir = '/tmp'
     f = 'motion.nii'
-    outlierfile, intensityfile, statsfile, normfile, plotfile = ad._get_output_filenames(f, outputdir)
+    (outlierfile, intensityfile, statsfile, normfile, plotfile,
+     displacementfile, maskfile) = ad._get_output_filenames(f, outputdir)
     yield assert_equal, outlierfile, '/tmp/art.motion_outliers.txt'
     yield assert_equal, intensityfile, '/tmp/global_intensity.motion.txt'
     yield assert_equal, statsfile, '/tmp/stats.motion.txt'
     yield assert_equal, normfile, '/tmp/norm.motion.txt'
     yield assert_equal, plotfile, '/tmp/plot.motion.png'
+    yield assert_equal, displacementfile, '/tmp/disp.motion.nii'
+    yield assert_equal, maskfile, '/tmp/mask.motion.nii'
 
 
 def test_ad_get_affine_matrix():
-    ad = ra.ArtifactDetect()
-    matrix = ad._get_affine_matrix(np.array([0]))
+    matrix = ra._get_affine_matrix(np.array([0]), 'SPM')
     yield assert_equal, matrix, np.eye(4)
     # test translation
     params = [1, 2, 3]
-    matrix = ad._get_affine_matrix(params)
+    matrix = ra._get_affine_matrix(params, 'SPM')
     out = np.eye(4)
     out[0:3, 3] = params
     yield assert_equal, matrix, out
     # test rotation
     params = np.array([0, 0, 0, np.pi / 2, np.pi / 2, np.pi / 2])
-    matrix = ad._get_affine_matrix(params)
+    matrix = ra._get_affine_matrix(params, 'SPM')
     out = np.array([0, 0, 1, 0, 0, -1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1]).reshape((4, 4))
     yield assert_almost_equal, matrix, out
     # test scaling
     params = np.array([0, 0, 0, 0, 0, 0, 1, 2, 3])
-    matrix = ad._get_affine_matrix(params)
+    matrix = ra._get_affine_matrix(params, 'SPM')
     out = np.array([1, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 0, 0, 0, 0, 1]).reshape((4, 4))
     yield assert_equal, matrix, out
     # test shear
     params = np.array([0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 3])
-    matrix = ad._get_affine_matrix(params)
+    matrix = ra._get_affine_matrix(params, 'SPM')
     out = np.array([1, 1, 2, 0, 0, 1, 3, 0, 0, 0, 1, 0, 0, 0, 0, 1]).reshape((4, 4))
     yield assert_equal, matrix, out
 
 
 def test_ad_get_norm():
-    ad = ra.ArtifactDetect()
     params = np.array([0, 0, 0, 0, 0, 0, 0, 0, 0, np.pi / 4, np.pi / 4,
                        np.pi / 4, 0, 0, 0, -np.pi / 4,
                        -np.pi / 4, -np.pi / 4]).reshape((3, 6))
-    norm = ad._calc_norm(params, False)
+    norm, _ = ra._calc_norm(params, False, 'SPM')
     yield assert_almost_equal, norm, np.array([18.86436316, 37.74610158, 31.29780829])
-    norm = ad._calc_norm(params, True)
+    norm, _ = ra._calc_norm(params, True, 'SPM')
     yield assert_almost_equal, norm, np.array([0., 143.72192614, 173.92527131])
 
 
