@@ -6,8 +6,9 @@
 import os
 import warnings
 
-from ...utils.filemanip import fname_presuffix
-from ..base import (CommandLine, traits, CommandLineInputSpec, isdefined)
+from ...utils.filemanip import fname_presuffix, split_filename
+from ..base import (
+    CommandLine, traits, CommandLineInputSpec, isdefined, File, TraitedSpec)
 
 warn = warnings.warn
 warnings.filterwarnings('always', category=UserWarning)
@@ -18,12 +19,13 @@ warnings.filterwarnings('always', category=UserWarning)
 #
 ###################################
 
+
 class Info(object):
     """Handle afni output type and version information.
     """
-    __outputtype = 'NIFTI_GZ'
+    __outputtype = 'AFNI'
     ftypes = {'NIFTI': '.nii',
-              'AFNI': '.BRIK',
+              'AFNI': '+orig.BRIK',
               'NIFTI_GZ': '.nii.gz'}
 
     @staticmethod
@@ -40,7 +42,8 @@ class Info(object):
            Version number as string or None if AFNI not found
 
         """
-        clout = CommandLine(command='afni_vcheck').run()
+        clout = CommandLine(command='afni_vcheck',
+                            terminal_output='allatonce').run()
         out = clout.runtime.stdout
         return out.split('\n')[1]
 
@@ -69,7 +72,7 @@ class Info(object):
     def outputtype(cls):
         """AFNI has no environment variables,
         Output filetypes get set in command line calls
-        Nipype uses NIFTI_GZ as default
+        Nipype uses AFNI as default
 
 
         Returns
@@ -78,15 +81,15 @@ class Info(object):
         """
         #warn(('AFNI has no environment variable that sets filetype '
         #      'Nipype uses NIFTI_GZ as default'))
-        return 'NIFTI_GZ'
-
+        return 'AFNI'
 
     @staticmethod
     def standard_image(img_name):
         '''Grab an image from the standard location.
 
         Could be made more fancy to allow for more relocatability'''
-        clout = CommandLine('which afni').run()
+        clout = CommandLine('which afni',
+                            terminal_output='allatonce').run()
         if clout.runtime.returncode is not 0:
             return None
 
@@ -95,23 +98,27 @@ class Info(object):
         return os.path.join(basedir, img_name)
 
 
-class AFNITraitedSpec(CommandLineInputSpec):
-    outputtype =  traits.Enum('NIFTI_GZ', Info.ftypes.keys(),
-                              desc = 'AFNI output filetype')
+class AFNIBaseCommandInputSpec(CommandLineInputSpec):
+    outputtype = traits.Enum('AFNI', Info.ftypes.keys(),
+                             desc='AFNI output filetype')
+    
+class AFNITraitedSpec(AFNIBaseCommandInputSpec):
+    pass
 
 
-class AFNICommand(CommandLine):
+class AFNIBaseCommand(CommandLine):
     """General support for AFNI commands. Every AFNI command accepts 'outputtype' input. For example:
     afni.Threedsetup(outputtype='NIFTI_GZ')
     """
 
-    input_spec = AFNITraitedSpec
+    input_spec = AFNIBaseCommandInputSpec
     _outputtype = None
+    
 
     def __init__(self, **inputs):
-        super(AFNICommand, self).__init__(**inputs)
+        super(AFNIBaseCommand, self).__init__(**inputs)
         self.inputs.on_trait_change(self._output_update, 'outputtype')
-
+        
         if self._outputtype is None:
             self._outputtype = Info.outputtype()
 
@@ -127,9 +134,8 @@ class AFNICommand(CommandLine):
         """
         self._outputtype = self.inputs.outputtype
 
-
     @classmethod
-    def set_default_outputtype(cls, outputtype):
+    def set_default_output_type(cls, outputtype):
         """Set the default output type for AFNI classes.
 
         This method is used to set the default output type for all afni
@@ -143,7 +149,7 @@ class AFNICommand(CommandLine):
         else:
             raise AttributeError('Invalid AFNI outputtype: %s' % outputtype)
 
-    def _gen_fname(self, basename, cwd=None, suffix='_afni', change_ext=True):
+    def _gen_fname(self, basename, cwd=None, suffix='_afni', change_ext=True, prefix=''):
         """Generate a filename based on the given parameters.
 
         The filename will take the form: cwd/basename<suffix><ext>.
@@ -181,9 +187,56 @@ class AFNICommand(CommandLine):
                 suffix = ''.join((suffix, ext))
             else:
                 suffix = ext
-        fname = fname_presuffix(basename, suffix = suffix,
-                                use_ext = False, newpath = cwd)
+        fname = fname_presuffix(basename, suffix=suffix,
+                                use_ext=False, newpath=cwd, prefix=prefix)
         return fname
 
 
+class AFNICommandInputSpec(AFNIBaseCommandInputSpec):
+    out_file = File("%s_afni", desc='output image file name',
+                    argstr='-prefix %s', xor=['out_file', 'prefix', 'suffix'], name_source="in_file", usedefault=True)
+    prefix = traits.Str(
+        desc='output image prefix', deprecated='0.8', new_name="out_file")
+    suffix = traits.Str(
+        desc='output image suffix', deprecated='0.8', new_name="out_file")
 
+
+class AFNICommand(AFNIBaseCommand):
+    input_spec = AFNICommandInputSpec
+
+    def _gen_filename(self, name):
+        trait_spec = self.inputs.trait(name)
+        if name == "out_file" and (isdefined(self.inputs.prefix) or isdefined(self.inputs.suffix)):
+            suffix = ''
+            prefix = ''
+            if isdefined(self.inputs.prefix):
+                prefix = self.inputs.prefix
+            if isdefined(self.inputs.suffix):
+                suffix = self.inputs.suffix
+
+            _, base, _ = split_filename(
+                getattr(self.inputs, trait_spec.name_source))
+            return self._gen_fname(basename=base, prefix=prefix, suffix=suffix, cwd=os.getcwd())
+        else:
+            return os.path.join(os.getcwd(),
+                                super(AFNICommand, self)._gen_filename(name))
+
+    def _overload_extension(self, value):
+        path, base, _ = split_filename(value)
+        return os.path.join(path, base + Info.outputtype_to_ext(self.inputs.outputtype))
+
+    def _list_outputs(self):
+        metadata = dict(name_source=lambda t: t is not None)
+        out_names = self.inputs.traits(**metadata).keys()
+        if out_names:
+            outputs = self.output_spec().get()
+            for name in out_names:
+                out = self._gen_filename(name)
+                if isdefined(out):
+                    outputs[name] = os.path.abspath(out)
+            return outputs
+
+
+class AFNICommandOutputSpec(TraitedSpec):
+    out_file = File(desc='output file',
+                    exists=True)
