@@ -7,5 +7,10 @@ from .ipythonx import IPythonXPlugin
 from .pbs import PBSPlugin
 from .sge import SGEPlugin
 from .condor import CondorPlugin
+from .dagman import CondorDAGManPlugin
 from .multiproc import MultiProcPlugin
 from .ipython import IPythonPlugin
+from .somaflow import SomaFlowPlugin
+from .pbsgraph import PBSGraphPlugin
+from .sgegraph import SGEGraphPlugin
+from .lsf import LSFPlugin
