@@ -3,12 +3,14 @@
 """Miscellaneous file manipulation functions
 
 """
+
+import cPickle
+from glob import glob
+import gzip
 import os
 import re
 import shutil
-from glob import glob
-import logging
-from nipype.utils.misc import isdefined
+
 # The md5 module is deprecated in Python 2.6, but hashlib is only
 # available as an external package for versions of python before 2.6.
 # Both md5 algorithms appear to return the same result.
@@ -27,8 +29,10 @@ except ImportError:
 
 import numpy as np
 
+from nipype.interfaces.traits_extension import isdefined
 from nipype.utils.misc import is_container
 
+from .. import logging, config
 fmlogger = logging.getLogger("filemanip")
 
 
@@ -50,7 +54,7 @@ def split_filename(fname):
     fname : str
         filename from fname, without extension
     ext : str
-        file extenstion from fname
+        file extension from fname
 
     Examples
     --------
@@ -67,14 +71,21 @@ def split_filename(fname):
 
     """
 
+    special_extensions = [".nii.gz", ".tar.gz"]
+
     pth, fname = os.path.split(fname)
-    tmp = '.none'
-    ext = []
-    while tmp:
-        fname, tmp = os.path.splitext(fname)
-        ext.append(tmp)
-    ext.reverse()
-    return pth, fname, ''.join(ext)
+
+    ext = None
+    for special_ext in special_extensions:
+        ext_len = len(special_ext)
+        if len(fname) > ext_len and fname[-ext_len:].lower() == special_ext.lower():
+            ext = fname[-ext_len:]
+            fname = fname[:-ext_len]
+            break
+    if not ext:
+        fname, ext = os.path.splitext(fname)
+
+    return pth, fname, ext
 
 def fname_presuffix(fname, prefix='', suffix='', newpath=None, use_ext=True):
     """Manipulates path and name of input filename
@@ -82,7 +93,7 @@ def fname_presuffix(fname, prefix='', suffix='', newpath=None, use_ext=True):
     Parameters
     ----------
     fname : string
-        A filename (may or may not include path
+        A filename (may or may not include path)
     prefix : string
         Characters to prepend to the filename
     suffix : string
@@ -126,7 +137,7 @@ def hash_rename(filename, hash):
     path, name, ext = split_filename(filename)
     newfilename = ''.join((name,'_0x', hash, ext))
     return os.path.join(path, newfilename)
-             
+
 
 def check_forhash(filename):
     """checks if file has a hash in its filename"""
@@ -162,12 +173,11 @@ def hash_timestamp(afile):
         md5obj = md5()
         stat = os.stat(afile)
         md5obj.update(str(stat.st_size))
-        md5obj.update(str(stat.st_ctime))
         md5obj.update(str(stat.st_mtime))
         md5hex = md5obj.hexdigest()
     return md5hex
 
-def copyfile(originalfile, newfile, copy=False):
+def copyfile(originalfile, newfile, copy=False, create_new=False, hashmethod=None):
     """Copy or symlink ``originalfile`` to ``newfile``.
 
     Parameters
@@ -178,26 +188,71 @@ def copyfile(originalfile, newfile, copy=False):
         full path to new file
     copy : Bool
         specifies whether to copy or symlink files
-        (default=False) but only for posix systems
-         
+        (default=False) but only for POSIX systems
+
     Returns
     -------
     None
-    
+
     """
-    if os.path.lexists(newfile):
-        fmlogger.warn("File: %s already exists, overwriting with %s, copy:%d" \
-            % (newfile, originalfile, copy))
+    newhash = None
+    orighash = None
+    fmlogger.debug(newfile)
+
+    if create_new:
+        while os.path.exists(newfile):
+            base, fname, ext = split_filename(newfile)
+            s = re.search('_c[0-9]{4,4}$',fname)
+            i = 0
+            if s:
+                i = int(s.group()[2:])+1
+                fname = fname[:-6] + "_c%04d"%i
+            else:
+                fname += "_c%04d"%i
+            newfile = base + os.sep + fname + ext
+
+    if hashmethod is None:
+        hashmethod = config.get('execution', 'hash_method').lower()
+
+    elif os.path.exists(newfile):
+        if hashmethod == 'timestamp':
+            newhash = hash_timestamp(newfile)
+        elif hashmethod == 'content':
+            newhash = hash_infile(newfile)
+        fmlogger.debug("File: %s already exists,%s, copy:%d" \
+                           % (newfile, newhash, copy))
+    #the following seems unnecessary
+    #if os.name is 'posix' and copy:
+    #    if os.path.lexists(newfile) and os.path.islink(newfile):
+    #        os.unlink(newfile)
+    #        newhash = None
     if os.name is 'posix' and not copy:
         if os.path.lexists(newfile):
-            os.unlink(newfile)
-        os.symlink(originalfile,newfile)
+            if hashmethod == 'timestamp':
+                orighash = hash_timestamp(originalfile)
+            elif hashmethod == 'content':
+                orighash = hash_infile(originalfile)
+            fmlogger.debug('Original hash: %s, %s'%(originalfile, orighash))
+            if newhash != orighash:
+                os.unlink(newfile)
+        if (newhash is None) or (newhash != orighash):
+            os.symlink(originalfile,newfile)
     else:
-        try:
-            shutil.copyfile(originalfile, newfile)
-        except shutil.Error, e:
-            fmlogger.warn(e.message)
-        
+        if newhash:
+            if hashmethod == 'timestamp':
+                orighash = hash_timestamp(originalfile)
+            elif hashmethod == 'content':
+                orighash = hash_infile(originalfile)
+        if (newhash is None) or (newhash != orighash):
+            try:
+                fmlogger.debug("Copying File: %s->%s" \
+                                  % (newfile, originalfile))
+                shutil.copyfile(originalfile, newfile)
+            except shutil.Error, e:
+                fmlogger.warn(e.message)
+        else:
+            fmlogger.debug("File: %s already exists, not overwriting, copy:%d" \
+                               % (newfile, copy))
     if originalfile.endswith(".img"):
         hdrofile = originalfile[:-4] + ".hdr"
         hdrnfile = newfile[:-4] + ".hdr"
@@ -206,8 +261,14 @@ def copyfile(originalfile, newfile, copy=False):
             matnfile = newfile[:-4] + ".mat"
             copyfile(matofile, matnfile, copy)
         copyfile(hdrofile, hdrnfile, copy)
+    elif originalfile.endswith(".BRIK"):
+        hdrofile = originalfile[:-4] + ".HEAD"
+        hdrnfile = newfile[:-4] + ".HEAD"
+        copyfile(hdrofile, hdrnfile, copy)
 
-def copyfiles(filelist, dest, copy=False):
+    return newfile
+
+def copyfiles(filelist, dest, copy=False, create_new=False):
     """Copy or symlink files in ``filelist`` to ``dest`` directory.
 
     Parameters
@@ -217,27 +278,27 @@ def copyfiles(filelist, dest, copy=False):
     dest : path/files
         full path to destination. If it is a list of length greater
         than 1, then it assumes that these are the names of the new
-        files. 
+        files.
     copy : Bool
         specifies whether to copy or symlink files
         (default=False) but only for posix systems
-         
+
     Returns
     -------
     None
-    
+
     """
     outfiles = filename_to_list(dest)
     newfiles = []
     for i,f in enumerate(filename_to_list(filelist)):
         if isinstance(f, list):
-            newfiles.insert(i, copyfiles(f, dest, copy=copy))
+            newfiles.insert(i, copyfiles(f, dest, copy=copy, create_new=create_new))
         else:
             if len(outfiles) > 1:
                 destfile = outfiles[i]
             else:
                 destfile = fname_presuffix(f, newpath=outfiles[0])
-            copyfile(f,destfile,copy)
+            destfile = copyfile(f,destfile,copy,create_new=create_new)
             newfiles.insert(i,destfile)
     return newfiles
 
@@ -254,7 +315,7 @@ def filename_to_list(filename):
         return None
 
 def list_to_filename(filelist):
-    """Returns a list if filelist is a list of length greater than 1, 
+    """Returns a list if filelist is a list of length greater than 1,
        otherwise returns the first element
     """
     if len(filelist) > 1:
@@ -268,10 +329,10 @@ def cleandir(dir):
     for ftype in filetypes:
         for f in glob(os.path.join(dir,ftype)):
             os.remove(f)
-        
+
 def save_json(filename, data):
     """Save data to a json file
-    
+
     Parameters
     ----------
     filename : str
@@ -301,7 +362,7 @@ def load_json(filename):
     Returns
     -------
     data : dict
-   
+
     """
 
     fp = file(filename, 'r')
@@ -326,4 +387,43 @@ def loadflat(infile, *args):
     return out
 
 def loadcrash(infile, *args):
-    return loadflat(infile, *args)
+    if '.pkl' in infile:
+        return loadpkl(infile)
+    else:
+        return loadflat(infile, *args)
+
+def loadpkl(infile):
+    """Load a zipped or plain cPickled file
+    """
+    if infile.endswith('pklz'):
+        pkl_file = gzip.open(infile, 'rb')
+    else:
+        pkl_file = open(infile)
+    return cPickle.load(pkl_file)
+
+def savepkl(filename, record):
+    if filename.endswith('pklz'):
+        pkl_file = gzip.open(filename, 'wb')
+    else:
+        pkl_file = open(filename, 'wb')
+    cPickle.dump(record, pkl_file)
+    pkl_file.close()
+
+rst_levels = ['=', '-', '~', '+']
+
+def write_rst_header(header, level=0):
+    return '\n'.join((header, ''.join([rst_levels[level] for _ in header])))+'\n\n'
+
+def write_rst_list(items, prefix=''):
+    out = []
+    for item in items:
+        out.append(prefix + ' ' + str(item))
+    return '\n'.join(out)+'\n\n'
+
+def write_rst_dict(info, prefix=''):
+    out = []
+    for key, value in sorted(info.items()):
+        out.append(prefix + '* ' + key + ' : ' + str(value))
+    return '\n'.join(out)+'\n\n'
+
+
