@@ -1,4 +1,4 @@
-from dti import create_bedpostx_pipeline, create_eddy_correct_pipeline
+from dti import create_bedpostx_pipeline, create_eddy_correct_pipeline, create_susceptibility_correct_pipeline, create_dmri_preprocessing
 from tbss import (create_tbss_1_preproc, create_tbss_2_reg,
                   create_tbss_3_postreg, create_tbss_4_prestats,
-                  create_tbss_all, create_tbss_non_FA)
\ No newline at end of file
+                  create_tbss_all, create_tbss_non_FA)
